Bootstrap estimate, standard error and confidence interval
Source:R/variance.R
bootstrap_estimate.RdApplies a statistic to the point weights and to every replicate, and summarises it with the bootstrap variance \((1/B)\sum(\theta^*_b - \hat\theta)^2\).
Usage
bootstrap_estimate(boot, statistic, level = 0.95)
boot_total(boot, variable)
boot_mean(boot, variable)