| jackknife_estimate | R Documentation |
Applies a statistic to the point weights and to every delete-a-PSU replicate, and summarises it with the stratified jackknife (JKn) variance
\sum_h \frac{n_h - 1}{n_h} \sum_{i \in h} (\theta_{(hi)} - \bar\theta_h)^2,
where \theta_{(hi)} is the estimate with PSU i of stratum h
deleted and \bar\theta_h the mean of those over the stratum. No finite
population correction is applied.
jackknife_estimate(jack, statistic, level = 0.95)
jack_total(jack, variable)
jack_mean(jack, variable)
jack |
a |
statistic |
a function |
level |
confidence level for the (normal) interval. |
variable |
name of the variable to estimate (for |
A data frame with estimate, se, ci_lower, ci_upper.
spec <- weighting_spec(sample_one, base_weights = pw) |>
step_calibrate(method = "raking",
margins = list(region = c(table(population$region))))
jk <- jackknife_weights(spec, strata = "region", psu = "psu", progress = FALSE)
jackknife_estimate(jk, function(w, d) sum(w * d$employed, na.rm = TRUE))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.