| weight_factors | R Documentation |
Returns a data.frame with the weight at each stage and the factor of each step (stage weight / previous-stage weight), handy for custom plots.
weight_factors(object)
object |
a prepped object (output of prep()). |
data.frame with one weight column per stage and one factor per step.
fitted <- weighting_spec(sample_survey, base_weights = pw) |>
step_nonresponse(respondent = responded, method = "weighting_class", by = "region") |>
prep()
head(weight_factors(fitted))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.